From e79275fbc653ee78f2a66a366f83924e29cf592c Mon Sep 17 00:00:00 2001
From: Stefano Rosati <stefano.rosati@cern.ch>
Date: Sat, 15 Feb 2025 17:26:41 +0100
Subject: [PATCH 1/5] modifying NRPC RDO

---
 Event/xAOD/xAODMuonRDO/Root/NRPCRDO_v1.cxx         |  6 +++---
 .../xAODMuonRDO/xAODMuonRDO/versions/NRPCRDO_v1.h  | 14 ++++++++------
 2 files changed, 11 insertions(+), 9 deletions(-)

diff --git a/Event/xAOD/xAODMuonRDO/Root/NRPCRDO_v1.cxx b/Event/xAOD/xAODMuonRDO/Root/NRPCRDO_v1.cxx
index d720283af097..db5bb5e943e0 100644
--- a/Event/xAOD/xAODMuonRDO/Root/NRPCRDO_v1.cxx
+++ b/Event/xAOD/xAODMuonRDO/Root/NRPCRDO_v1.cxx
@@ -29,9 +29,9 @@ namespace xAOD{
 IMPLEMENT_SETTER_GETTER( uint32_t, bcid, setBcid)
 IMPLEMENT_SETTER_GETTER( float, time, setTime)
 IMPLEMENT_SETTER_GETTER( uint16_t, subdetector, setSubdetector)
-IMPLEMENT_SETTER_GETTER( uint16_t, tdcsector, setTdcsector)
-IMPLEMENT_SETTER_GETTER( uint16_t, tdc, setTdc)
+IMPLEMENT_SETTER_GETTER( uint16_t, boardsector, setBoardsector)
+IMPLEMENT_SETTER_GETTER( uint16_t, board, setBoard)
 IMPLEMENT_SETTER_GETTER( uint16_t, channel, setChannel)
 IMPLEMENT_SETTER_GETTER( float, timeoverthr, setTimeoverthr)
 }
-#undef IMPLEMENT_SETTER_GETTER
\ No newline at end of file
+#undef IMPLEMENT_SETTER_GETTER
diff --git a/MuonSpectrometer/MuonCablings/MuonCablingData/src/RpcCablingData.cxx b/MuonSpectrometer/MuonCablings/MuonCablingData/src/RpcCablingData.cxx
index f091d93eaf1e..afc99e3b0ddb 100644
--- a/MuonSpectrometer/MuonCablings/MuonCablingData/src/RpcCablingData.cxx
+++ b/MuonSpectrometer/MuonCablings/MuonCablingData/src/RpcCablingData.cxx
@@ -21,8 +21,8 @@ namespace Muon{
     }
     std::ostream& operator<<(std::ostream& ostr, const RpcCablingOnlineID& obj) {
         ostr << std::format("subDetector: {:3d} ",obj.subDetector);
-        ostr << std::format("tdcSector: {:2d} ", obj.tdcSector);
-        ostr << std::format("tdc: {:2d} ", obj.tdc);
+        ostr << std::format("boardSector: {:2d} ", obj.boardSector);
+        ostr << std::format("board: {:2d} ", obj.board);
         return ostr;
     }
     std::ostream& operator<<(std::ostream& ostr, const RpcCablingData& obj) {
diff --git a/MuonSpectrometer/MuonCablings/MuonCablingData/src/RpcCablingMap.cxx b/MuonSpectrometer/MuonCablings/MuonCablingData/src/RpcCablingMap.cxx
index 2f93ccb45388..e89fe8b95091 100644
--- a/MuonSpectrometer/MuonCablings/MuonCablingData/src/RpcCablingMap.cxx
+++ b/MuonSpectrometer/MuonCablings/MuonCablingData/src/RpcCablingMap.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
 */
 #include "MuonCablingData/RpcCablingMap.h"
 #include "MuonCablingData/RpcFlatCableTranslator.h"
@@ -150,7 +150,7 @@ namespace Muon {
         }
 
         int sub = entry.subDetector;
-        int rod = entry.tdcSector;
+        int rod = entry.boardSector;
 
         int32_t hardId = (sub << 16) | rod;
 
@@ -185,7 +185,7 @@ namespace Muon {
                         << ": Failed to generate a hash for " << chamber.gasGapID << endmsg;
                     return false;
                 }
-                uint32_t hardId = (card.subDetector << 16) | card.tdcSector;
+                uint32_t hardId = (card.subDetector << 16) | card.boardSector;
                 m_chambROBs[hash] = hardId;
                 std::vector<IdentifierHash>& robHashes = m_ROBHashes[hardId];
                 if (std::ranges::find(robHashes, hash) == robHashes.end()){
@@ -248,4 +248,4 @@ namespace Muon {
         }
         return cables;
     }
-}
\ No newline at end of file
+}
diff --git a/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/MuonRdoToMuonDigitTool.cxx b/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/MuonRdoToMuonDigitTool.cxx
index 376f9f4f782b..73c4f16c6d1b 100644
--- a/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/MuonRdoToMuonDigitTool.cxx
+++ b/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/MuonRdoToMuonDigitTool.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2023 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
 */
 
 // algorithm to decode RDO into digits
@@ -702,15 +702,15 @@ StatusCode MuonRdoToMuonDigitTool::decodeNRpcRDO(const EventContext& ctx, RpcDig
     
     /// Loop over the container
     for (const xAOD::NRPCRDO* rdo : *rdoContainer) {
-        ATH_MSG_VERBOSE("Convert RDO tdcSector: "<< static_cast<int>(rdo->tdcsector())<<", tdc:"
-                <<static_cast<int>(rdo->tdc())<<" channel: "<<static_cast<int>(rdo->channel()) <<", time: "<<
+        ATH_MSG_VERBOSE("Convert RDO boardSector: "<< static_cast<int>(rdo->boardsector())<<", tdc:"
+                <<static_cast<int>(rdo->board())<<" channel: "<<static_cast<int>(rdo->channel()) <<", time: "<<
                 rdo->time()<<", ToT: "<<rdo->timeoverthr());
         
         /// Fill the cabling object
         CablingData conv_obj{};
         conv_obj.subDetector = rdo->subdetector();
-        conv_obj.tdcSector = rdo->tdcsector();
-        conv_obj.tdc = rdo->tdc();
+        conv_obj.boardSector = rdo->boardsector();
+        conv_obj.board = rdo->board();
         conv_obj.channelId = rdo->channel();
         
         if (!cabling->getOfflineId(conv_obj, msgStream())) {
diff --git a/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/NrpcDigitToNrpcRDO.cxx b/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/NrpcDigitToNrpcRDO.cxx
index 148674be0fdf..b81ffb15a123 100644
--- a/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/NrpcDigitToNrpcRDO.cxx
+++ b/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/NrpcDigitToNrpcRDO.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "MuonByteStreamCnvTest/NrpcDigitToNrpcRDO.h"
@@ -130,8 +130,8 @@ StatusCode NrpcDigitToNrpcRDO::execute(const EventContext& ctx) const {
             NrpcRdo->setBcid(the_bcid);
             NrpcRdo->setTime(rdo_time);
             NrpcRdo->setSubdetector(cabling_data.subDetector);
-            NrpcRdo->setTdcsector(cabling_data.tdcSector);
-            NrpcRdo->setTdc(cabling_data.tdc);
+            NrpcRdo->setBoardsector(cabling_data.boardSector);
+            NrpcRdo->setBoard(cabling_data.board);
             NrpcRdo->setChannel(cabling_data.channelId);
             NrpcRdo->setTimeoverthr(the_timeoverthr);
         }
diff --git a/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/RpcRdoToRpcDigit.cxx b/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/RpcRdoToRpcDigit.cxx
index 201ac93a4184..4b7b0839841e 100644
--- a/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/RpcRdoToRpcDigit.cxx
+++ b/MuonSpectrometer/MuonCnv/MuonByteStreamCnvTest/src/RpcRdoToRpcDigit.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2023 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "RpcRdoToRpcDigit.h"
@@ -138,15 +138,15 @@ StatusCode RpcRdoToRpcDigit::decodeNRpc(const EventContext& ctx, RpcDigitContain
     std::map<IdentifierHash, std::unique_ptr<RpcDigitCollection>> digit_map{};
     /// Loop over the container
     for (const xAOD::NRPCRDO* rdo : *rdoContainer) {
-        ATH_MSG_VERBOSE("Convert RDO tdcSector: "<< static_cast<int>(rdo->tdcsector())<<", tdc:"
-                <<static_cast<int>(rdo->tdc())<<" channel: "<<static_cast<int>(rdo->channel()) <<", time: "<<
+        ATH_MSG_VERBOSE("Convert RDO boardSector: "<< static_cast<int>(rdo->boardsector())<<", tdc:"
+                <<static_cast<int>(rdo->board())<<" channel: "<<static_cast<int>(rdo->channel()) <<", time: "<<
                 rdo->time()<<", ToT: "<<rdo->timeoverthr());
         
         /// Fill the cabling object
         Muon::RpcCablingData conv_obj{};
         conv_obj.subDetector = rdo->subdetector();
-        conv_obj.tdcSector = rdo->tdcsector();
-        conv_obj.tdc = rdo->tdc();
+        conv_obj.boardSector = rdo->boardsector();
+        conv_obj.board = rdo->board();
         conv_obj.channelId = rdo->channel();
         
         if (!cabling->getOfflineId(conv_obj, msgStream())) {
diff --git a/MuonSpectrometer/MuonCnv/MuonRPC_CnvTools/src/RpcRdoToPrepDataToolMT.cxx b/MuonSpectrometer/MuonCnv/MuonRPC_CnvTools/src/RpcRdoToPrepDataToolMT.cxx
index 3a8df3629b02..312a7cc3d0d8 100755
--- a/MuonSpectrometer/MuonCnv/MuonRPC_CnvTools/src/RpcRdoToPrepDataToolMT.cxx
+++ b/MuonSpectrometer/MuonCnv/MuonRPC_CnvTools/src/RpcRdoToPrepDataToolMT.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2023 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "RpcRdoToPrepDataToolMT.h"
@@ -1277,8 +1277,8 @@ StatusCode Muon::RpcRdoToPrepDataToolMT::processNrpcRdo(const EventContext& ctx,
         /// Convert from online to offline cabling
         RpcCablingData cabling_data{};
         cabling_data.subDetector = nrpcrdo->subdetector();
-        cabling_data.tdcSector = nrpcrdo->tdcsector();
-        cabling_data.tdc = nrpcrdo->tdc();
+        cabling_data.boardSector = nrpcrdo->boardsector();
+        cabling_data.board = nrpcrdo->board();
         cabling_data.channelId = nrpcrdo->channel();
         Identifier chanId{};
         if (!readCdo->getOfflineId(cabling_data, msgStream()) ||
-- 
GitLab


From 00ec729dfb1366b7b27982164f5da6c4a798635e Mon Sep 17 00:00:00 2001
From: Stefano Rosati <stefano.rosati@cern.ch>
Date: Sat, 15 Feb 2025 21:30:41 +0100
Subject: [PATCH 3/5] NRPC cabling namings

---
 .../MuonCablings/MuonNRPC_Cabling/src/NRpcCablingAlg.cxx  | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/MuonSpectrometer/MuonCablings/MuonNRPC_Cabling/src/NRpcCablingAlg.cxx b/MuonSpectrometer/MuonCablings/MuonNRPC_Cabling/src/NRpcCablingAlg.cxx
index 2264896899ce..eb318caa7e76 100644
--- a/MuonSpectrometer/MuonCablings/MuonNRPC_Cabling/src/NRpcCablingAlg.cxx
+++ b/MuonSpectrometer/MuonCablings/MuonNRPC_Cabling/src/NRpcCablingAlg.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "NRpcCablingAlg.h"
@@ -112,8 +112,8 @@ StatusCode NRpcCablingAlg::parsePayload(RpcCablingMap& cabling_map,
         cabl_data.gasGap = cabl_payload["gasGap"];
         /// Online part
         cabl_data.subDetector = cabl_payload["subDetector"];
-        cabl_data.tdcSector = cabl_payload["tdcSector"];
-        cabl_data.tdc = cabl_payload["tdc"];
+        cabl_data.boardSector = cabl_payload["boardSector"];
+        cabl_data.board = cabl_payload["board"];
         cabl_data.firstStrip = cabl_payload["firstStrip"];
         unsigned int flatCable = cabl_payload["flatCableId"];
         if (!readoutCards[flatCable]) {
@@ -127,4 +127,4 @@ StatusCode NRpcCablingAlg::parsePayload(RpcCablingMap& cabling_map,
     }
     return StatusCode::SUCCESS;
 }
-}
\ No newline at end of file
+}
-- 
GitLab


From 073e1b2b5d6002019ed983202235eaa3c32940c1 Mon Sep 17 00:00:00 2001
From: Stefano Rosati <stefano.rosati@cern.ch>
Date: Mon, 17 Feb 2025 14:07:47 +0100
Subject: [PATCH 4/5] fix json file preparation of NRC cabling

---
 .../python/createCablingJSON.py                | 18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

diff --git a/MuonSpectrometer/MuonCablings/MuonNRPC_Cabling/python/createCablingJSON.py b/MuonSpectrometer/MuonCablings/MuonNRPC_Cabling/python/createCablingJSON.py
index 77b27579545f..814fff5ba939 100644
--- a/MuonSpectrometer/MuonCablings/MuonNRPC_Cabling/python/createCablingJSON.py
+++ b/MuonSpectrometer/MuonCablings/MuonNRPC_Cabling/python/createCablingJSON.py
@@ -1,4 +1,4 @@
-# Copyright (C) 2002-2024 CERN for the benefit of the ATLAS collaboration
+# Copyright (C) 2002-2025 CERN for the benefit of the ATLAS collaboration
 import json
 from copy import deepcopy
 
@@ -55,7 +55,7 @@ for sector in range(1, 9):
                     "gasGap": gasGap + 1,
                     ### Online part
                     "subDetector": sub_detector,
-                    "tdcSector" : sector*2+16, # sector A2 -> 0x0012, sector A4 -> 0x0014, ..., sector A12 -> 0x001c, ...,           
+                    "boardSector" : sector*2+16, # sector A2 -> 0x0012, sector A4 -> 0x0014, ..., sector A12 -> 0x001c, ...,           
                     "flatCableId" : 0,
                 }
                 ### TDC 
@@ -67,7 +67,7 @@ for sector in range(1, 9):
                         cabling_data["firstTdcChan"] = 0
                         cabling_data["lastTdcChan"] = 31  # Standard: 32 channels per TDC
                         """
-                        cabling_data["tdc"] = gasGap
+                        cabling_data["board"] = gasGap
                     elif doubZ == 2: ## BIS8
                         cabling_data["firstStrip"] = 1  # MN: Problem: should firstStrip be -15, to start with strip 1 in channel 17?
                         """                        
@@ -75,7 +75,7 @@ for sector in range(1, 9):
                         cabling_data["firstTdcChan"] = 16
                         cabling_data["lastTdcChan"] = 31  # Last 16 TDC channels
                         """
-                        cabling_data["tdc"] = gasGap + 9
+                        cabling_data["board"] = gasGap + 9
                         cabling_data["flatCableId"] = 1
                     idTranslateDict.append(deepcopy(cabling_data))
 
@@ -87,7 +87,7 @@ for sector in range(1, 9):
                         cabling_data["firstTdcChan"] = 1
                         cabling_data["lastTdcChan"] = 32  # Standard: 32 channels per TDC
                         """
-                        cabling_data["tdc"] = gasGap + 3
+                        cabling_data["board"] = gasGap + 3
                     elif doubZ == 2: ## BIS8
                         cabling_data["firstStrip"] = 1
                         """
@@ -95,7 +95,7 @@ for sector in range(1, 9):
                         cabling_data["firstTdcChan"] = 0
                         cabling_data["lastTdcChan"] = 31  # Standard: 32 channels per TDC
                         """
-                        cabling_data["tdc"] = gasGap + 12
+                        cabling_data["board"] = gasGap + 12
                     idTranslateDict.append(deepcopy(cabling_data))
                     if doubZ == 1: ## BIS7
                         cabling_data["firstStrip"] = 33
@@ -104,7 +104,7 @@ for sector in range(1, 9):
                         cabling_data["firstTdcChan"] = 0
                         cabling_data["lastTdcChan"] = 31  # Standard: 32 channels per TDC
                         """
-                        cabling_data["tdc"] = gasGap + 6
+                        cabling_data["board"] = gasGap + 6
                     elif doubZ == 2: ## BIS8
                         cabling_data["firstStrip"] = 33
                         """
@@ -112,7 +112,7 @@ for sector in range(1, 9):
                         cabling_data["firstTdcChan"] = 0
                         cabling_data["lastTdcChan"] = 31  # Standard: 32 channels per TDC
                         """
-                        cabling_data["tdc"] = gasGap + 15
+                        cabling_data["board"] = gasGap + 15
 
                     idTranslateDict.append(deepcopy(cabling_data))
 
@@ -127,7 +127,7 @@ for sector in range(1, 9):
                         cabling_data["firstTdcChan"] = 0
                         cabling_data["lastTdcChan"] = 7  # First 8 channels of the TDC used for BIS8 eta strips
                         """
-                        cabling_data["tdc"] = gasGap + 9
+                        cabling_data["board"] = gasGap + 9
                         cabling_data["flatCableId"] = 2
                         idTranslateDict.append(deepcopy(cabling_data))
 
-- 
GitLab


From ee71154ea48529164b04156e56bc8d4d0cbdfaa3 Mon Sep 17 00:00:00 2001
From: Stefano Rosati <stefano.rosati@cern.ch>
Date: Mon, 17 Feb 2025 15:22:04 +0100
Subject: [PATCH 5/5] updating RPC cabling map version

---
 MuonSpectrometer/MuonConfig/python/MuonCablingConfig.py | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/MuonSpectrometer/MuonConfig/python/MuonCablingConfig.py b/MuonSpectrometer/MuonConfig/python/MuonCablingConfig.py
index 9f5e48b3e473..1b404d3a9190 100644
--- a/MuonSpectrometer/MuonConfig/python/MuonCablingConfig.py
+++ b/MuonSpectrometer/MuonConfig/python/MuonCablingConfig.py
@@ -12,7 +12,7 @@ def NRPCCablingConfigCfg(flags, name = "MuonNRPC_CablingAlg", **kwargs):
         from IOVDbSvc.IOVDbSvcConfig import addFolders
         dbName = 'RPC_OFL' if flags.Input.isMC else 'RPC'
         cablingFolder = "/RPC/NCABLING/JSON" if flags.Input.isMC else "/RPC/Onl/NCABLING/JSON"
-        cablingTag = "RpcNcablingJson-RUN3-07"
+        cablingTag = "RpcNcablingJson-RUN3-08"
         from AthenaConfiguration.Enums import LHCPeriod
         if flags.Muon.usePhaseIIGeoSetup and flags.Input.isMC:  
             if flags.GeoModel.Run <= LHCPeriod.Run3:   
diff --git a/Event/xAOD/xAODMuonRDO/xAODMuonRDO/versions/NRPCRDO_v1.h b/Event/xAOD/xAODMuonRDO/xAODMuonRDO/versions/NRPCRDO_v1.h
index 568bfd409186..a136cb95de91 100644
--- a/Event/xAOD/xAODMuonRDO/xAODMuonRDO/versions/NRPCRDO_v1.h
+++ b/Event/xAOD/xAODMuonRDO/xAODMuonRDO/versions/NRPCRDO_v1.h
@@ -29,9 +29,10 @@ namespace xAOD {
         /// Global identifier of the RPC detector region from the online side
         uint16_t subdetector() const;
         /// Identifier of the sector within the subdetector
-        uint16_t tdcsector() const;
+        uint16_t boardsector() const;
         /// Identifier of the readout card on the chamber
-        uint16_t tdc() const;
+        /// For BIS 7/8 this is a TDC, for NRPC in run4 is a DCT
+        uint16_t board() const;
         /// Fired channel on the read out card
         uint16_t channel() const;
         /// Measured time in which the signal was above the electronics threshold
@@ -45,10 +46,11 @@ namespace xAOD {
         void setTimeoverthr(float Timeoverthr);
         /// Set the sub detector
         void setSubdetector(uint16_t SubDet);
-        /// Set the sector of the tdc within the subdetector
-        void setTdcsector(uint16_t Tdcsector);
-        /// Set the number of the TDC channel
-        void setTdc(uint16_t Tdc);
+        /// Set the sector of the board within the subdetector
+        void setBoardsector(uint16_t Boardsector);
+        /// Set the number of the Board channel
+        /// For BIS 7/8 this is a TDC, for NRPC in run4 is a DCT
+        void setBoard(uint16_t Board);
         /// Set the fire channel number
         void setChannel(uint16_t Channel);
     };
-- 
GitLab


From c9ce6df814d1bfb0ee22f85ba3c81e3640af6532 Mon Sep 17 00:00:00 2001
From: Stefano Rosati <stefano.rosati@cern.ch>
Date: Sat, 15 Feb 2025 18:17:19 +0100
Subject: [PATCH 2/5] fix NRDO dependencies

---
 .../MuonCablingData/RpcCablingData.h           |  8 ++++----
 .../MuonCablingData/src/RpcCablingData.cxx     |  4 ++--
 .../MuonCablingData/src/RpcCablingMap.cxx      |  8 ++++----
 .../src/MuonRdoToMuonDigitTool.cxx             | 10 +++++-----
 .../src/NrpcDigitToNrpcRDO.cxx                 |  6 +++---
 .../src/RpcRdoToRpcDigit.cxx                   | 10 +++++-----
 .../src/NRPC_RawDataProviderTool.cxx           | 18 +++++++++---------
 .../src/RpcRdoToPrepDataToolMT.cxx             |  6 +++---
 8 files changed, 35 insertions(+), 35 deletions(-)

diff --git a/MuonSpectrometer/MuonCablings/MuonCablingData/MuonCablingData/RpcCablingData.h b/MuonSpectrometer/MuonCablings/MuonCablingData/MuonCablingData/RpcCablingData.h
index cfec8cfd4bc9..fe81d1821bf5 100644
--- a/MuonSpectrometer/MuonCablings/MuonCablingData/MuonCablingData/RpcCablingData.h
+++ b/MuonSpectrometer/MuonCablings/MuonCablingData/MuonCablingData/RpcCablingData.h
@@ -79,9 +79,9 @@ namespace Muon{
         /** @brief  Identifier of the subdetector region in the readout BA / BC etc. */
         int16_t& subDetector{m_cache.cache[0]};
         /** @brief Unique Identifier of the Rpc chamber from an online perspective  */
-        int16_t& tdcSector{m_cache.cache[1]};
+        int16_t& boardSector{m_cache.cache[1]};
         /** @brief Unique identifier of the tdc chip */
-        int16_t& tdc{m_cache.cache[2]};
+        int16_t& board{m_cache.cache[2]};
     private:
         union {
             int64_t hash{0};
@@ -96,7 +96,7 @@ namespace Muon{
         RpcCablingData() = default;
         /** @brief Offline strip number */
         uint8_t strip{0};
         /** @brief Online tdc channel number */
         uint8_t channelId{0};
         /** @brief No sorting operator */
         bool operator<(const RpcCablingData&) const = delete;
@@ -118,4 +118,4 @@ namespace Muon{
 }
 
 #undef CABLING_OPERATORS
-#endif
\ No newline at end of file
+#endif
@@ -96,7 +96,7 @@ namespace Muon{
         /** @brief Offline strip number */
         uint8_t strip{0};
-        /** @brief Online tdc channel number */
+        /** @brief Online board channel number */
         uint8_t channelId{0};
         /** @brief No sorting operator */
diff --git a/MuonSpectrometer/MuonCnv/MuonRPC_CnvTools/src/NRPC_RawDataProviderTool.cxx b/MuonSpectrometer/MuonCnv/MuonRPC_CnvTools/src/NRPC_RawDataProviderTool.cxx
index 4cc2de0d6c00..145fdf197f75 100644
--- a/MuonSpectrometer/MuonCnv/MuonRPC_CnvTools/src/NRPC_RawDataProviderTool.cxx
+++ b/MuonSpectrometer/MuonCnv/MuonRPC_CnvTools/src/NRPC_RawDataProviderTool.cxx
@@ -133,14 +133,14 @@ StatusCode NRPC_RawDataProviderTool::fillCollections(const OFFLINE_FRAGMENTS_NAM
     uint32_t sourceId = robFrag.source_id();
     uint32_t rod_sourceId = robFrag.rod_source_id();
 
     // Unpack sub-detector and tdc sector from sourceId
     uint16_t subDetector = sourceId >> 16;
-    uint16_t tdcSector = (sourceId & 0x00ffff);
+    uint16_t boardSector = (sourceId & 0x00ffff);
 
     ATH_MSG_VERBOSE("ROD version: " << MSG::hex << version << MSG::dec << "  ROB source ID: " << MSG::hex << sourceId << MSG::dec
                                     << "  ROD source ID: " << MSG::hex << rod_sourceId << MSG::dec << "  Subdetector: " << MSG::hex
-                                    << subDetector << MSG::dec << "  tdcSector: " << std::hex 
-                                    << tdcSector << std::dec );
+                                    << subDetector << MSG::dec << "  boardSector: " << std::hex 
+                                    << boardSector << std::dec );
 
 
 
@@ -155,9 +155,9 @@ StatusCode NRPC_RawDataProviderTool::fillCollections(const OFFLINE_FRAGMENTS_NAM
     unsigned int idata=0;
     while (idata<data_size) {
         if (data[idata]==6 && data[idata+4]==0xa0 && data[idata+5]==0) {
-            ATH_MSG_DEBUG("NRPC: Empty tdc " << std::hex << data[idata+4] << std::dec << " for " << std::hex << data[idata+1] << std::dec );
+            ATH_MSG_DEBUG("NRPC: Empty board " << std::hex << data[idata+4] << std::dec << " for " << std::hex << data[idata+1] << std::dec );
         } else if (data[idata]<6) {
-            WARNING_WITH_LINE("NRPC: Corrupted: Number of words from tdc " << std::hex << data[idata+4] << std::dec << " is <6 :" << data[idata] );
+            WARNING_WITH_LINE("NRPC: Corrupted: Number of words from board " << std::hex << data[idata+4] << std::dec << " is <6 :" << data[idata] );
             break;
         } else if ( (data[idata+data[idata]-2] & 0x000000ff) != 0xa0) {
             WARNING_WITH_LINE("NRPC: Missing expected trailer a0" );
@@ -173,7 +173,7 @@ StatusCode NRPC_RawDataProviderTool::fillCollections(const OFFLINE_FRAGMENTS_NAM
             
             // Decode data
             for (unsigned int i=0; i<data[idata]-6; i++) {
-                uint16_t tdc = (data[idata+4+i] & 0x000000ff) ;
+                uint16_t board = (data[idata+4+i] & 0x000000ff) ;
                 uint16_t chan = (data[idata+4+i] & 0x0000ff00) >> 8 ;
                 float tot = ((data[idata+4+i] & 0x007f0000) >> 16)*0.4 ;
                 float time = ((data[idata+4+i] & 0x0f000000) >> 24)*1.6 ;
@@ -194,8 +194,8 @@ StatusCode NRPC_RawDataProviderTool::fillCollections(const OFFLINE_FRAGMENTS_NAM
                 NrpcRdo->setBcid(bcid);
                 NrpcRdo->setTime(time);
                 NrpcRdo->setSubdetector(subDetector);
-                NrpcRdo->setTdcsector(tdcSector);
-                NrpcRdo->setTdc(tdc);
+                NrpcRdo->setBoardsector(boardSector);
+                NrpcRdo->setBoard(board);
                 NrpcRdo->setChannel(chan);
                 NrpcRdo->setTimeoverthr(tot);
 
@@ -133,14 +133,14 @@ StatusCode NRPC_RawDataProviderTool::fillCollections(const OFFLINE_FRAGMENTS_NAM
     uint32_t rod_sourceId = robFrag.rod_source_id();
 
-    // Unpack sub-detector and tdc sector from sourceId
+    // Unpack sub-detector and board sector from sourceId
     uint16_t subDetector = sourceId >> 16;
-- 
GitLab